<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>DatabaseUpdater</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="77"/>
        <source>Your dosage database needs to be updated from version 0.5.0 to version 0.5.4.
This will be automatically done.</source>
        <translation>Votre base de données de protocoles nécessite une mise à jour depuis la version 0.5.0 vers la version 0.5.4.
Ceci va êetre réalisé automatiquement.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="187"/>
        <source>Your dosage database needs to be updated from version 0.4.0 to version 0.5.0.
This will be automatically done.</source>
        <translation>Votre base de données de protocoles nécessite une mise à jour depuis la version 0.4.0 vers la version 0.5.0.
Ceci va êetre réalisé automatiquement.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="297"/>
        <source>Your dosage database needs to be updated from version 0.2.0 to version 0.4.0.
This will be automatically done.</source>
        <translation>Votre base de données de protocoles nécessite une mise à jour depuis la version 0.2.0 vers la version 0.4.0.
Ceci va êetre réalisé automatiquement.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="401"/>
        <source>Your dosage database needs to be updated from version 0.0.8 to version 0.2.0.
This will be automatically done.
Please verify your daily scheme prescriptions and relations to meal.</source>
        <translation>Votre base de données posologique a besoin d&apos;être mise à jour de la version 0.0.8 à la version 0.2.0.
Ceci va être se faire automatiquement.
Veuillez vérifier vos répartitions journalières et vos relations avec le repas.</translation>
    </message>
</context>
<context>
    <name>DrugsBase</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/engines/drugdruginteractionengine.cpp" line="975"/>
        <source>FreeDiams Interactions Engine</source>
        <translation>Moteur d&apos;interaction de FreeDiams</translation>
    </message>
</context>
<context>
    <name>DrugsDB::AtcTreeModel</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="341"/>
        <source>Label</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="343"/>
        <source>Code</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DrugsDB::DrugsBasePlugin</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbaseplugin.cpp" line="115"/>
        <source>Initializing drugs database plugin...</source>
        <translation>Initialisation du plugin des bases de données thérapeutique...</translation>
    </message>
</context>
<context>
    <name>DrugsDB::DrugsIO</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="538"/>
        <source>Dosages transmitted.</source>
        <translation>Posologies transmises.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="541"/>
        <source>Dosage not correctly transmitted</source>
        <translation>Posologies incorrectement transmises</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="583"/>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="602"/>
        <source>You are trying to read a corrupted XML file.</source>
        <translation>Le fichier que vous tentez de lire est corrompu.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="584"/>
        <source>Error: %1
Line: %2, Column: %3</source>
        <translation>Erreur : %1
Ligne : %2, colonne : %3</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="601"/>
        <source>Unable to load XML prescription : tag %1 is missing</source>
        <translation>Impossible d&apos;ouvrir la prescription XML : le tag %1 est manquant</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="603"/>
        <source>Missing tag: %1</source>
        <translation>Tag XML manquant : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="653"/>
        <source>Interaction checking will not take these drugs into account.
</source>
        <translation>Le moteur d&apos;interaction ne prendra pas en compte ces médicaments.
</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="654"/>
        <source>FreeDiams encountered errors while reading the XML prescription.</source>
        <translation>FreeDiams a rencontré des erreurs lors de la lecture de la prescription.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="665"/>
        <source>Xml prescription correctly read.</source>
        <translation>Prescription XML correctement ouverte.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="697"/>
        <source>No file name passed to load prescription</source>
        <translation>Aucun nom de fichier donné pour l&apos;ouverture d&apos;une prescription</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="871"/>
        <source>Save test only drugs too ?</source>
        <translation>Sauvegarder les médicaments tests aussi ?</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="872"/>
        <source>Drugs added for testing only are actually hidden in this prescription.
Do you want to add them to the file ?</source>
        <translation>Les médicaments tests sont actuellement cachés dans la prescription.
Voulez-vous les ajouter au fichier ?</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="874"/>
        <source>Answering &apos;no&apos; will cause definitive lost of test only drugs when reloading this file.</source>
        <translation>Répondre &apos;non&apos; peut causer une perte définitive d&apos;informations des médicaments tests lors de la prochaine ouverture.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="1093"/>
        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="1107"/>
        <source>Drugs Prescription</source>
        <translation>Prescription Medicamenteuse</translation>
    </message>
</context>
<context>
    <name>DrugsDB::DrugsModel</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="515"/>
        <source>KNOWN ALLERGY</source>
        <translation>ALLERGIE CONNUE</translation>
    </message>
</context>
<context>
    <name>DrugsDB::GlobalDrugsModel</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="390"/>
        <source>KNOWN ALLERGY</source>
        <translation>ALLERGIE CONNUE</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="394"/>
        <source>KNOWN INTOLERANCE</source>
        <translation>INTOLÉRANCE CONNUE</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="434"/>
        <source>Identifier(s): </source>
        <translation>Identifiant(s) : </translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="432"/>
        <source>Form(s): </source>
        <translation>Forme(s) : </translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="433"/>
        <source>Route(s): </source>
        <translation>Voie(s) d&apos;administration : </translation>
    </message>
</context>
<context>
    <name>DrugsDB::Internal::DosageModel</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="134"/>
        <source>complet tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="135"/>
        <source>half tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="136"/>
        <source>quater tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="140"/>
        <source>dose per kilograms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="141"/>
        <source>reference spoon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="142"/>
        <source>2.5 ml spoon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="143"/>
        <source>5 ml spoon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="144"/>
        <source>puffs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="145"/>
        <source>dose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="146"/>
        <source>mouthwash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="147"/>
        <source>inhalation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="148"/>
        <source>application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="149"/>
        <source>washing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="150"/>
        <source>shampooing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="151"/>
        <source>eyewash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="152"/>
        <source>instillation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="153"/>
        <source>pulverization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="344"/>
        <source>Model Error : unable to insert a row</source>
        <translation>Erreur du modèle : Impossible d&apos;insérer une ligne</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="508"/>
        <source>The intakes&apos; scheme must be defined.</source>
        <translation>Le schéma de prise doit être défini.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="510"/>
        <source>The period&apos;s scheme must be defined.</source>
        <translation>Le schéma de période doit être défini.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="513"/>
        <source>The duration&apos;s scheme must be defined.</source>
        <translation>Le schema de durée doit être défini.</translation>
    </message>
</context>
<context>
    <name>DrugsDB::Internal::DrugAllergyEngine</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/engines/allergyengine.cpp" line="514"/>
        <source>Detects allergies and intolerances to medications</source>
        <translation>Détecte les allergies et intolérances médicamenteuses</translation>
    </message>
</context>
<context>
    <name>DrugsDB::Internal::DrugDrugInteractionEngine</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/engines/drugdruginteractionengine.cpp" line="824"/>
        <source>Detects interaction between drugs</source>
        <translation>Détecte les interaction entre les médicaments</translation>
    </message>
</context>
<context>
    <name>DrugsDB::Internal::DrugsBase</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="619"/>
        <source>Searching databases into dir %1</source>
        <translation>Recherche des bases de données dans le répertoire %1</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="632"/>
        <source>No drugs database found.</source>
        <translation>Pas de base de données thérapeutique trouvée.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="643"/>
        <source>Drug database source does not exists.</source>
        <translation>La source de données n&apos;existe pas.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="644"/>
        <source>Switching to the default drugs database source.</source>
        <translation>Revenir à la base de données par défaut.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="991"/>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="997"/>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1002"/>
        <source>Unable to create the Protocol database.</source>
        <translation>Impossible de créer la base de données Protocoles.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="991"/>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="997"/>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1002"/>
        <source>Please contact dev team.</source>
        <translation>Veuillez contacter l&apos;équipe de développement.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1115"/>
        <source>Unable to update the protocol&apos;s transmission date.</source>
        <translation>Impossible de mettre à jour la date de transmission des protocoles.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1344"/>
        <source>No drug database source selected</source>
        <translation>Pas de source pour la base de données thérapeutique sélectionné</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1346"/>
        <source>No drugs database loaded.</source>
        <translation>Pas de base de données thérapeutique chargée.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1364"/>
        <source>Asking for a drug without UID</source>
        <translation>Requête d&apos;un médicament sant UID</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1500"/>
        <source>Unable to find drug with DID %1</source>
        <translation>Impossible de trouver le médicament avec le DID %1</translation>
    </message>
</context>
<context>
    <name>DrugsDB::Internal::DrugsTemplatePrinter</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="66"/>
        <source>Warning : </source>
        <translation>Attention : </translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="68"/>
        <source>Interactions found. </source>
        <translation>Interactions trouvées. </translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="70"/>
        <source>Allergies found. </source>
        <translation>Allergies trouvées. </translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="75"/>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="80"/>
        <source>What do you want to do ?</source>
        <translation>Que voulez-vous faire ?</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="88"/>
        <source>Synthetic interactions</source>
        <translation>Synthèse des interactions</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="101"/>
        <source>Print separately or merge printing.</source>
        <translation>Imprimer séparemment ou fusionner pour l&apos;impression.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="102"/>
        <source>You have selected multiple templates, would you print them separately or merge templates for printing on a single order ?</source>
        <translation>Vous avez sélectionné plusieurs modèles, voulez-vous les imprimer séparément ou les fusionner pour les imprimer sur la même ordonnance ?</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="105"/>
        <source>Print separately</source>
        <translation>Imprimer séparément</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="105"/>
        <source>Merge and print</source>
        <translation>Fusionner et imprimer</translation>
    </message>
</context>
<context>
    <name>DrugsDB::Internal::PimEngine</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/engines/pimengine.cpp" line="767"/>
        <source>(Experimental)</source>
        <translation>(Expérimental)</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/engines/pimengine.cpp" line="777"/>
        <source>Detects interaction between drugs and patient in elderly</source>
        <translation>Détecte les interactions entre médicaments et personnes âgées</translation>
    </message>
</context>
<context>
    <name>DrugsData</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="809"/>
        <source>No INN found.</source>
        <translation>Pas de DCI connue.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="814"/>
        <source>No interaction class found.</source>
        <translation>Pas de classe d&apos;interaction connue.</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="852"/>
        <source>Form(s): </source>
        <translation>Forme(s) : </translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="853"/>
        <source>Route(s): </source>
        <translation>Voie(s) d&apos;administration : </translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="854"/>
        <source>Identifier(s): </source>
        <translation>Identifiant(s) : </translation>
    </message>
</context>
<context>
    <name>DrugsModel</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="245"/>
        <source>x %1 of %2</source>
        <translation>x %1 de %2</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="254"/>
        <source>Available Dosages</source>
        <translation>Dosages disponibles</translation>
    </message>
</context>
<context>
    <name>mfDrugsConstants</name>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="80"/>
        <source>&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;[[DRUG]]&lt;/span&gt;&lt;span style=&quot;font-style:italic;&quot;&gt;[&lt;br /&gt;Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][&lt;br /&gt;Route: [ROUTE]][&lt;br /&gt;Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][&lt;br /&gt;Minimum interval between intakes: [MIN_INTERVAL]][&lt;br /&gt;[NOTE] ]&lt;/span&gt;&lt;/p&gt;</source>
        <translation>&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;[[DRUG]]&lt;/span&gt;&lt;span style=&quot;font-style:italic;&quot;&gt;[&lt;br /&gt;Prendre [Q_FROM]][ à [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ tous les [[PERIOD] ][PERIOD_SCHEME]][ pendant [D_FROM]][ à [D_TO]][ [D_SCHEME]][&lt;br /&gt;Par voie : [ROUTE]][&lt;br /&gt;Distribution journalière : [DISTRIBUTED_DAILY_SCHEME]][&lt;br /&gt;Intervalle minimum entre les prises : [MIN_INTERVAL]][&lt;br /&gt;[NOTE] ]&lt;/span&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="88"/>
        <source>[[DRUG]][
Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][
Route: [ROUTE]][
Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][
Minimum interval between intakes: [MIN_INTERVAL]][
[NOTE] ]</source>
        <translation>[[DRUG]][
Prendre [Q_FROM]][ à [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ tous les [[PERIOD] ][PERIOD_SCHEME]][ pendant [D_FROM]][ à [D_TO]][ [D_SCHEME]][
Par voie : [ROUTE]][
Distribution journalière : [DISTRIBUTED_DAILY_SCHEME]][
Intervalle minimum entre les prises : [MIN_INTERVAL]][
[NOTE] ]</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="255"/>
        <source>Nature of risk</source>
        <translation>Nature du risque</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="256"/>
        <source>Management</source>
        <translation>Prise en charge</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="257"/>
        <source>Drug-drug interactions</source>
        <translation>Interactions médicamenteuses</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="260"/>
        <source>DDI</source>
        <extracomment>This is the short name of the Drug-drug interactions engine.</extracomment>
        <translation>IAM</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="262"/>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="266"/>
        <source>Potentially inappropriate medications</source>
        <translation>Médications potentiellement inappropriés</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="265"/>
        <source>PIM</source>
        <extracomment>This is the short name of the Potentially inappropriate medications engine.</extracomment>
        <translation>MPI</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="269"/>
        <source>Allergy / Intolerances to medications</source>
        <translation>Allergies / intolerances aux médicaments</translation>
    </message>
    <message>
        <location filename="../../plugins/drugsbaseplugin/constants.h" line="272"/>
        <source>Allergy</source>
        <extracomment>This is the short name of the Potentially inappropriate medications engine.</extracomment>
        <translation>Allergies</translation>
    </message>
</context>
</TS>
